@@ -98,25 +98,26 @@ class Country(Enum):
 
     @staticmethod
     def fromString(string):
-        if string == 'Chile':
+        string = string.lower()
+        if string == 'Chile'.lower():
             return Country.Country_Chile
-        elif string == 'Colombia':
+        elif string == 'Colombia'.lower():
             return Country.Country_Colombia
-        elif string == 'Peru':
+        elif string == 'Peru'.lower():
             return Country.Country_Peru
-        elif string == 'Mexico':
+        elif string == 'Mexico'.lower():
             return Country.Country_Mexico
-        elif string == 'Argentina':
+        elif string == 'Argentina'.lower():
             return Country.Country_Argentina
-        elif string == 'United States':
+        elif string == 'United States'.lower():
             return Country.Country_United_States
-        elif string == 'Europe':
+        elif string == 'Europe'.lower():
             return Country.Country_Europe
-        elif string == 'Japan':
+        elif string == 'Japan'.lower():
             return Country.Country_Japan
-        elif string == 'International':
+        elif string == 'International'.lower():
             return Country.Country_International
-        elif string == 'Risk Factors' or string == 'RiskFactors':
+        elif string == 'Risk Factors'.lower() or string == 'RiskFactors'.lower():
             return Country.Country_RiskFactors
         else:
             return Country.Country_Unspecified
