@@ -152,14 +152,6 @@ class Report(metaclass=ABCMeta):
         print(f"URL: {url}.")
         argDict["variant"] = variant
 
-        # message: Message.Report = Message.Report(document=document,
-        #                                          chapter=chapter,
-        #                                          item="report",
-        #                                          variant=variant,
-        #                                          dateEffective=dateEffective,
-        #                                          section=section,
-        #                                          subsection=subsection,
-        #                                          paragraph=paragraph)
         message: Message.Report = Message.Report(**argDict)
         return message
 
@@ -488,8 +480,7 @@ class Report(metaclass=ABCMeta):
 
         p.makePlot(df=df,
                    shape=tuple(int(dim * self._BASE_PLOT_RESOLUTION)
-                               for dim in shape
-                               ),
+                               for dim in shape),
                    backend=self._plotBackend)
         self.setImage(tag=tag,
                       path=p.pathImage,
